@@ -33,9 +33,12 @@ from dagster.core.definitions import (
     TypeCheck,
     UrlMetadataEntryData,
     composite_solid,
+    default_executors,
     executor,
+    in_process_executor,
     lambda_solid,
     logger,
+    multiprocess_executor,
     pipeline,
     resource,
     schedules,
@@ -70,10 +73,19 @@ from dagster.core.execution.context.init import InitResourceContext
 from dagster.core.execution.context.logger import InitLoggerContext
 from dagster.core.execution.context.system import SystemComputeExecutionContext
 from dagster.core.execution.plan.objects import StepKind
-from dagster.core.execution.results import PipelineExecutionResult, SolidExecutionResult
+from dagster.core.execution.results import (
+    CompositeSolidExecutionResult,
+    PipelineExecutionResult,
+    SolidExecutionResult,
+)
 from dagster.core.log_manager import DagsterLogManager
 from dagster.core.storage.file_manager import FileHandle, LocalFileHandle
 from dagster.core.storage.init import InitSystemStorageContext
+from dagster.core.storage.system_storage import (
+    default_system_storage_defs,
+    fs_system_storage,
+    mem_system_storage,
+)
 from dagster.core.types import (
     Any,
     Bool,
