@@ -166,15 +166,15 @@ class _SchedulerHandle(object):
 
 
 def schedules(scheduler):
-    '''
-    Create a scheduler with a ``Scheduler`` implementation and set of ``ScheduleDefinitions``.
+    '''Create a scheduler with a :py:class:`~dagster.core.scheduler.Scheduler` implementation and
+    set of :py:class:`ScheduleDefinition` instances.
 
-    Decorate a function that returns a list of ``ScheduleDefinitions``. The
-    decorator has an argument that takes a ``Scheduler`` implementation, such as
-    ``SystemCronScheduler``.
+    Decorate a function that returns a list of :py:class:`ScheduleDefinition`. The decorator has
+    an argument that takes a :py:class:`~dagster.core.scheduler.Scheduler` implementation, such as
+    :py:func:`~dagster_cron.SystemCronScheduler`.
 
     Args:
-        scheduler (Scheduler): The ``Scheduler`` implementation to use
+        scheduler (Scheduler): The scheduler implementation to use.
 
     Examples:
 
@@ -756,7 +756,7 @@ def composite_solid(
     )
 
 
-class _Pipeline:
+class _Pipeline(object):
     def __init__(self, name=None, mode_defs=None, preset_defs=None, description=None):
         self.name = check.opt_str_param(name, 'name')
         self.mode_definitions = check.opt_list_param(mode_defs, 'mode_defs', ModeDefinition)
