@@ -3,9 +3,14 @@ from collections import namedtuple
 from dagster.core.definitions import SolidHandle
 from dagster.core.errors import DagsterInvalidDefinitionError
 from dagster.core.types import Field, List, NamedDict, NamedSelector
-from dagster.core.types.config import ALL_CONFIG_BUILTINS, ConfigType, ConfigTypeAttributes
+from dagster.core.types.config import (
+    ALL_CONFIG_BUILTINS,
+    ConfigType,
+    ConfigTypeAttributes,
+    ConfigTypeKind,
+)
 from dagster.core.types.field import check_opt_field_param
-from dagster.core.types.field_utils import _ConfigComposite
+from dagster.core.types.field_utils import _ConfigHasFields
 from dagster.core.types.iterate_types import iterate_config_types
 from dagster.core.types.runtime import construct_runtime_type_dictionary
 from dagster.utils import camelcase, check, ensure_single_item
@@ -23,7 +28,7 @@ def SystemNamedDict(name, fields, description=None):
     return NamedDict(name, fields, description, ConfigTypeAttributes(is_system_config=True))
 
 
-class _SolidContainerConfigDict(_ConfigComposite):
+class _SolidContainerConfigDict(_ConfigHasFields):
     def __init__(self, name, fields, description=None, handle=None, child_solids_config_field=None):
         self._handle = check.opt_inst_param(handle, 'handle', SolidHandle)
         self._child_solids_config_field = check.opt_inst_param(
@@ -33,6 +38,7 @@ class _SolidContainerConfigDict(_ConfigComposite):
         super(_SolidContainerConfigDict, self).__init__(
             key=name,
             name=name,
+            kind=ConfigTypeKind.DICT,
             fields=fields,
             description=description,
             type_attributes=ConfigTypeAttributes(is_system_config=True),
@@ -73,6 +79,37 @@ def SystemNamedSelector(name, fields, description=None):
     return NamedSelector(name, fields, description, ConfigTypeAttributes(is_system_config=True))
 
 
+class _SolidConfigDict(_ConfigHasFields):
+    def __init__(self, name, fields, description):
+
+        super(_SolidConfigDict, self).__init__(
+            key=name,
+            name=name,
+            kind=ConfigTypeKind.DICT,
+            fields=fields,
+            description=description,
+            type_attributes=ConfigTypeAttributes(is_system_config=True),
+        )
+
+
+def SolidConfigDict(name, fields, description=None):
+    from dagster.core.types.field_utils import check_user_facing_fields_dict
+
+    check_user_facing_fields_dict(fields, 'NamedDict named "{}"'.format(name))
+
+    class _SolidConfigDictInternal(_SolidConfigDict):
+        def __init__(self):
+            super(_SolidConfigDictInternal, self).__init__(
+                name=name, fields=fields, description=description
+            )
+
+    return _SolidConfigDictInternal
+
+
+def is_solid_dict(obj):
+    return isinstance(obj, _SolidConfigDict)
+
+
 def is_solid_container_config(obj):
     return isinstance(obj, _SolidContainerConfigDict)
 
@@ -139,9 +176,7 @@ class EnvironmentClassCreationData(
             dependency_structure=check.inst_param(
                 dependency_structure, 'dependency_structure', DependencyStructure
             ),
-            mode_definition=check.opt_inst_param(
-                mode_definition, 'mode_definition', ModeDefinition
-            ),
+            mode_definition=check.inst_param(mode_definition, 'mode_definition', ModeDefinition),
             logger_defs=check.dict_param(
                 logger_defs, 'logger_defs', key_type=str, value_type=LoggerDefinition
             ),
@@ -188,9 +223,7 @@ def define_environment_cls(creation_data):
     return SolidContainerConfigDict(
         name='{pipeline_name}.Mode.{mode_name}.Environment'.format(
             pipeline_name=pipeline_name, mode_name=camelcase(creation_data.mode_definition.name)
-        )
-        if creation_data.mode_definition
-        else '{pipeline_name}.Environment'.format(pipeline_name=pipeline_name),
+        ),
         fields=remove_none_entries(
             {
                 'solids': Field(
@@ -421,7 +454,7 @@ def define_solid_dictionary_cls(
                 pipeline_name,
             )
 
-    return SystemNamedDict(name, fields)
+    return SolidConfigDict(name, fields)
 
 
 def iterate_solid_def_types(solid_def):
